Welcome to django-urlprepend
===========================

This Django application you to prepend a string to your django app urls useful if you need to change themes based on url.

.. comment: split here

The urlprepend code is licensed under the `MIT License`_. See the
``LICENSE.txt`` file in the distribution.

.. _`MIT License`: http://www.opensource.org/licenses/mit-license.php


Documentation
-------------

.. toctree::
	:maxdepth: 2

	setup
	usage
	history
